==> zio-aws-lightsail_2.12-5.17.295.6-sources.jar: zio/aws/lightsail/model/GetRelationalDatabaseParametersResponse.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetRelationalDatabaseParametersResponse(
    parameters: Optional[
      Iterable[zio.aws.lightsail.model.RelationalDatabaseParameter]
    ] = Optional.Absent,
    nextPageToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseParametersResponse = {
    import GetRelationalDatabaseParametersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseParametersResponse
      .builder()
      .optionallyWith(
        parameters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.parameters)
      .optionallyWith(nextPageToken.map(value => value: java.lang.String))(
        _.nextPageToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse.ReadOnly =
    zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse
      .wrap(buildAwsValue())
}
object GetRelationalDatabaseParametersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseParametersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse =
      zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse(
        parameters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextPageToken.map(value => value)
      )
    def parameters: Optional[
      List[zio.aws.lightsail.model.RelationalDatabaseParameter.ReadOnly]
    ]
    def nextPageToken: Optional[String]
    def getParameters: ZIO[Any, AwsError, List[
      zio.aws.lightsail.model.RelationalDatabaseParameter.ReadOnly
    ]] = AwsError.unwrapOptionField("parameters", parameters)
    def getNextPageToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextPageToken", nextPageToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseParametersResponse
  ) extends zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse.ReadOnly {
    override val parameters: Optional[
      List[zio.aws.lightsail.model.RelationalDatabaseParameter.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.parameters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lightsail.model.RelationalDatabaseParameter.wrap(item)
        }.toList
      )
    override val nextPageToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextPageToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseParametersResponse
  ): zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/GetRelationalDatabaseParametersResponse.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetRelationalDatabaseParametersResponse(
    parameters: Option[
      Iterable[zio.aws.lightsail.model.RelationalDatabaseParameter]
    ] = None,
    nextPageToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseParametersResponse = {
    import GetRelationalDatabaseParametersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseParametersResponse
      .builder()
      .optionallyWith(
        parameters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.parameters)
      .optionallyWith(nextPageToken.map(value => value: java.lang.String))(
        _.nextPageToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse.ReadOnly =
    zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse
      .wrap(buildAwsValue())
}
object GetRelationalDatabaseParametersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseParametersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse =
      zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse(
        parameters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextPageToken.map(value => value)
      )
    def parameters: Option[
      List[zio.aws.lightsail.model.RelationalDatabaseParameter.ReadOnly]
    ]
    def nextPageToken: Option[String]
    def getParameters: ZIO[Any, AwsError, List[
      zio.aws.lightsail.model.RelationalDatabaseParameter.ReadOnly
    ]] = AwsError.unwrapOptionField("parameters", parameters)
    def getNextPageToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextPageToken", nextPageToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseParametersResponse
  ) extends zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse.ReadOnly {
    override val parameters: Option[
      List[zio.aws.lightsail.model.RelationalDatabaseParameter.ReadOnly]
    ] = scala
      .Option(impl.parameters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lightsail.model.RelationalDatabaseParameter.wrap(item)
        }.toList
      )
    override val nextPageToken: Option[String] =
      scala.Option(impl.nextPageToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseParametersResponse
  ): zio.aws.lightsail.model.GetRelationalDatabaseParametersResponse.ReadOnly =
    new Wrapper(impl)
}
